@@ -4,9 +4,7 @@ from pyunitx.force import pounds
 from pyunitx.length import feet
 from pyunitx.time import Time, seconds
 
-
-
-Power = make_compound_dimension({Energy: 1, Time: -1})
+Power = make_compound_dimension(exponents={Energy: 1, Time: -1}, name="Power")
 
 watts = make_compound_unit(
     name="watts",
@@ -20,7 +18,7 @@ watts = make_compound_unit(
     """
 )
 
-generated = si_unit(base_unit=watts, short_doc=":class:`watts` are the SI base unit of power.")
+generated = si_unit(base_unit=watts)
 globals().update(generated)
 
 kilowatts = make_compound_unit(
@@ -44,9 +42,11 @@ horsepower = make_compound_unit(
     standards-compliant equine.
     """
 )
+
 __all__ = [
-              "Power",
-              "watts",
-              "kilowatts",
-              "horsepower",
-          ] + list(generated.keys())
+    "Power",
+    "watts",
+    "kilowatts",
+    "horsepower",
+    *generated.keys()
+]
