@@ -14,10 +14,11 @@ volts = make_compound_unit(
     """
 )
 
-generated = si_unit(base_unit=volts, short_doc="")
+generated = si_unit(base_unit=volts)
 globals().update(generated)
 
 __all__ = [
-              "Potential",
-              "volts",
-          ] + list(generated.keys())
+    "Potential",
+    "volts",
+    *generated.keys()
+]
